AccountLimit Methods — Rucio 1.2 documentation

# AccountLimit Methods

class `rucio.client.accountlimitclient.` `AccountLimitClient`(rucio_host=None, auth_host=None, account=None, ca_cert=None, auth_type=None, creds=None, timeout=600, user_agent='rucio-clients')

  Bases: `rucio.client.baseclient.BaseClient`

  Account limit client class for working with account limits

  `ACCOUNTLIMIT_BASEURL` = 'accountlimits'
  `delete_account_limit`(account, rse)

    Sends the request to remove an account limit.

    Parameters: | account – The name of the account. rse – The rse name.
    Returns: | True if quota was removed successfully. False otherwise.
    Raises: | AccountNotFound – if account doesn’t exist.

  `set_account_limit`(account, rse, bytes)

    Sends the request to set an account limit for an account.

    Parameters: | account – The name of the account. rse – The rse name. bytes – An integer with the limit in bytes.
    Returns: | True if quota was created successfully else False.